==> gene2pathway_2.2.0.zip: gene2pathway/doc/gene2pathway.R <==
###################################################
### chunk number 1: no.nonsense
###################################################
#line 45 "gene2pathway.Rnw"
rm(list=ls())


###################################################
### chunk number 2: 
###################################################
#line 84 "gene2pathway.Rnw"
library(gene2pathway)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 87 "gene2pathway.Rnw"
## gene2pathway("FBgn0030327", flyBase=TRUE, organism="dme") 


###################################################
### chunk number 4: 
###################################################
#line 90 "gene2pathway.Rnw"
pred.comp = gene2pathway.signaltrans("387129", organism="hsa") # prediction of the signaling pathway component for Entrez gene ID 387129 for human
pred.comp


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 94 "gene2pathway.Rnw"
## url = color.pathway.by.elements("path:hsa04020",pred.comp$elemIDs[["387129"]])


###################################################
### chunk number 6: 
###################################################
#line 101 "gene2pathway.Rnw"
data(classificationModel_dme)     # load the bagged model
modelKEGG[[1]]$allpathways        # all employed KEGG hierarchy levels
modelKEGG[[1]]$used_domains[[10]] # Which InterPro domains are used by the first model to detect Phosphatidylinositol signaling?
modelKEGG[[2]]$W                  # How are input code vectors weighted?


###################################################
### chunk number 7: 
###################################################
#line 120 "gene2pathway.Rnw"
toLatex(sessionInfo())

==> gene2pathway_2.6.0.zip: gene2pathway/doc/gene2pathway.R <==
### R code from vignette source 'gene2pathway.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: no.nonsense
###################################################
rm(list=ls())


###################################################
### code chunk number 2: gene2pathway.Rnw:83-84
###################################################
library(gene2pathway)


###################################################
### code chunk number 3: gene2pathway.Rnw:86-87 (eval = FALSE)
###################################################
## gene2pathway("FBgn0030327", flyBase=TRUE, organism="dme") 


###################################################
### code chunk number 4: gene2pathway.Rnw:89-91
###################################################
pred.comp = gene2pathway.signaltrans("43856", organism="dme") # prediction of the signaling pathway component for Entrez gene ID 387129 for human
pred.comp


###################################################
### code chunk number 5: gene2pathway.Rnw:93-94 (eval = FALSE)
###################################################
## url = color.pathway.by.elements("path:dme04630",pred.comp$elemIDs[["43856"]])


###################################################
### code chunk number 6: gene2pathway.Rnw:100-104
###################################################
data(classificationModel_dme)     # load the bagged model
modelKEGG[[1]]$allpathways        # all employed KEGG hierarchy levels
modelKEGG[[1]]$used_domains[[10]] # Which InterPro domains are used by the first model to detect Phosphatidylinositol signaling?
modelKEGG[[2]]$W                  # How are input code vectors weighted?


###################################################
### code chunk number 7: gene2pathway.Rnw:119-120
###################################################
toLatex(sessionInfo())
